# Banking API

Use Codat's API to connect to your SMB customer's banks and pull up-to-date standardized account and transaction data from their bank accounts via our partner providers.

<!-- Start SDK Installation -->
## SDK Installation

```bash
pip install codat-banking
```
<!-- End SDK Installation -->

## SDK Example Usage
<!-- Start SDK Example Usage -->
```python
import codatbanking
from codatbanking.models import operations

s = codatbanking.CodatBanking(
    security=shared.Security(
        auth_header="YOUR_API_KEY_HERE",
    ),
)


req = operations.ListAccountBalancesRequest(
    company_id='8a210b68-6988-11ed-a1eb-0242ac120002',
    connection_id='2e9d2c44-f675-40ba-8049-353bfcb5e171',
    order_by='-modifiedDate',
    page=1,
    page_size=100,
    query='corrupti',
)

res = s.account_balances.list(req)

if res.account_balances is not None:
    # handle response
```
<!-- End SDK Example Usage -->

<!-- Start SDK Available Operations -->
## Available Resources and Operations


### [account_balances](docs/accountbalances/README.md)

* [list](docs/accountbalances/README.md#list) - List account balances

### [accounts](docs/accounts/README.md)

* [get](docs/accounts/README.md#get) - Get account
* [list](docs/accounts/README.md#list) - List accounts

### [transaction_categories](docs/transactioncategories/README.md)

* [get](docs/transactioncategories/README.md#get) - Get transaction category
* [list](docs/transactioncategories/README.md#list) - List all transaction categories

### [transactions](docs/transactions/README.md)

* [get](docs/transactions/README.md#get) - Get bank transaction
* [list](docs/transactions/README.md#list) - List transactions
<!-- End SDK Available Operations -->

### SDK Generated by [Speakeasy](https://docs.speakeasyapi.dev/docs/using-speakeasy/client-sdks)
